mesos

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 8, 2025 License: GPL-3.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Firecracker

type Firecracker struct {
	Ctx         context.Context
	ID          string
	Machine     *firecracker.Machine
	IP          net.IP
	Socket      string
	Driver      *mesosdriver.ExecutorDriver
	MesosConfig *config.Config
	Settings    map[string]string
	Started     bool
	Task        *mesos.TaskInfo
	Kill        bool
	Payload     bool
}

func NewExecutor

func NewExecutor(mesosConfig *config.Config, settings map[string]string) *Firecracker

NewExecutor returns a properly configured sidecarExecutor.

func (*Firecracker) Heartbeat

func (e *Firecracker) Heartbeat()

Heartbeat of the vmm-agent

func (*Firecracker) KillTask

func (e *Firecracker) KillTask()

KillTask is a Mesos callback that will try very hard to kill off a running task/container.

func (*Firecracker) LaunchTask

func (e *Firecracker) LaunchTask(taskInfo *mesos.TaskInfo)

handleLaunch puts given task in unacked tasks and launches it

Jump to